@@ -1,10 +1,10 @@
 package AnyEvent::Processor;
 #ABSTRACT: Base class to define an event-driven (AnyEvent) task that could periodically be interrupted by a watcher
-$AnyEvent::Processor::VERSION = '0.005';
+$AnyEvent::Processor::VERSION = '0.006';
 use Moose;
-
-use 5.010;
+use Modern::Perl;
 use AnyEvent;
+use Glib;
 use AnyEvent::Processor::Watcher;
 
 with 'AnyEvent::Processor::WatchableTask';
@@ -24,7 +24,7 @@ has blocking => ( is => 'rw', isa => 'Bool', default => 0 );
 
 sub run {
     my $self = shift;
-    if ( $self->blocking) {
+    if ( $self->blocking ) {
         $self->run_blocking();
     }
     else {
@@ -47,21 +47,20 @@ sub run_task {
     $self->start_process();
 
     if ( $self->verbose ) {
-        $self->watcher( AnyEvent::Processor::Watcher->new(
-            delay => 1, action => $self ) ) unless $self->watcher;
+        $self->watcher(
+            AnyEvent::Processor::Watcher->new( delay => 1, action => $self )
+        ) unless $self->watcher;
         $self->watcher->start();
     }
 
     my $end_run = AnyEvent->condvar;
-    my $idle = AnyEvent->idle(
-        cb => sub {
-            unless ( $self->process() ) {
-                $self->end_process();
-                $self->watcher->stop() if $self->watcher;
-                $end_run->send;
-            }
+    my $idle = AnyEvent->idle( cb => sub {
+        unless ( $self->process() ) {
+            $self->end_process();
+            $self->watcher->stop() if $self->watcher;
+            $end_run->send;
         }
-    );
+    });
     $end_run->recv;
 }
 
@@ -70,7 +69,7 @@ sub start_process { }
 
 
 sub start_message {
-    print "Start process...\n";
+    say "Start process";
 }
 
 
@@ -83,7 +82,7 @@ sub process {
 
 sub process_message {
     my $self = shift;
-    print sprintf("  %#6d", $self->count), "\n";    
+    say sprintf("  %#6d", $self->count);    
 }
 
 
@@ -92,7 +91,7 @@ sub end_process { return 0; }
 
 sub end_message {
     my $self = shift; 
-    print "Number of items processed: ", $self->count, "\n";
+    say "Number of items processed: ", $self->count;
 }
 
 
@@ -113,7 +112,7 @@ AnyEvent::Processor - Base class to define an event-driven (AnyEvent) task that
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -244,7 +243,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Fréderic Demians.
+This software is Copyright (c) 2015 by Fréderic Demians.
 
 This is free software, licensed under:
 
